pub enum DrawState {
Unset,
Culled,
PassThrough,
Visible {
vis_flags: PrimitiveVisibilityFlags,
sub_slice_index: SubSliceIndex,
},
}Expand description
Contains the current state of the primitive’s visibility.
Variants
Unset
Uninitialized - this should never be encountered after prim reset
Culled
Culled for being off-screen, or not possible to render (e.g. missing image resource)
PassThrough
A picture that doesn’t have a surface - primitives are composed into the parent picture with a surface.
Visible
A primitive that has been found to be visible
Fields

vis_flags: PrimitiveVisibilityFlagsA set of flags that define how this primitive should be handled during batching of visible primitives.

sub_slice_index: SubSliceIndexSub-slice within the picture cache that this prim exists on